@@ -93,6 +93,11 @@ class GeneratePPT(Logger):
 
         # self.remove_proc_slides(self._generate_procs)
 
+        if app_cnt == 1: 
+            s = self._ppt.get_shape_by_name('port_level_slide')
+            pass
+            #self._ppt.delete_slide
+
         self._ppt.duplicate_slides(app_cnt)
         self._ppt.copy_block("each_app",["app"],app_cnt)
 
