@@ -440,24 +440,30 @@ class HLData(HLRestCall):
                     self._data[s]['cve_med_tot']=0
                     self._data[s]['cve_med_comp_tot']=0
                 else:
-                    self._data[s]['cve_crit_tot']=len(cves[cves['criticity']=='CRITICAL']['cve'].unique())
-                    self._data[s]['cve_crit_comp_tot']=len(cves[cves['criticity']=='CRITICAL']['component'].unique())
-                    self._data[s]['cve_high_tot']=len(cves[cves['criticity']=='HIGH']['cve'].unique())
-                    self._data[s]['cve_high_comp_tot']=len(cves[cves['criticity']=='HIGH']['component'].unique())
-                    self._data[s]['cve_med_tot']=len(cves[cves['criticity']=='MEDIUM']['cve'].unique())
-                    self._data[s]['cve_med_comp_tot']=len(cves[cves['criticity']=='MEDIUM']['component'].unique())
+                    if cves.empty:
+                        self.warning('No Vulnerabililty information available')
+                    else:
+                        self._data[s]['cve_crit_tot']=len(cves[cves['criticity']=='CRITICAL']['cve'].unique())
+                        self._data[s]['cve_crit_comp_tot']=len(cves[cves['criticity']=='CRITICAL']['component'].unique())
+                        self._data[s]['cve_high_tot']=len(cves[cves['criticity']=='HIGH']['cve'].unique())
+                        self._data[s]['cve_high_comp_tot']=len(cves[cves['criticity']=='HIGH']['component'].unique())
+                        self._data[s]['cve_med_tot']=len(cves[cves['criticity']=='MEDIUM']['cve'].unique())
+                        self._data[s]['cve_med_comp_tot']=len(cves[cves['criticity']=='MEDIUM']['component'].unique())
                 
                 if lic is None:
                     self._data[s]['lic_high_tot']=0
                     self._data[s]['lic_med_tot']=0
                 else:
                     # make some adjustment since HL data has changed
-                    lic['compliance']=lic['compliance'].str.replace('compliant','high')
-                    lic['compliance']=lic['compliance'].str.replace('partial','medium')
-                    lic['compliance']=lic['compliance'].str.replace('notCompliant','low')
+                    if cves.empty:
+                        self.warning('No License information available')
+                    else:
+                        lic['compliance']=lic['compliance'].str.replace('compliant','high')
+                        lic['compliance']=lic['compliance'].str.replace('partial','medium')
+                        lic['compliance']=lic['compliance'].str.replace('notCompliant','low')
 
-                    self._data[s]['lic_high_tot']=len(lic[lic['compliance']=='low']['component'].unique())
-                    self._data[s]['lic_med_tot']=len(lic[lic['compliance']=='medium']['component'].unique())
+                        self._data[s]['lic_high_tot']=len(lic[lic['compliance']=='low']['component'].unique())
+                        self._data[s]['lic_med_tot']=len(lic[lic['compliance']=='medium']['component'].unique())
 
                 self._data[s]['total_components']=total_components
             else:
